( cd usr/lib ; rm -rf libgii.so )
( cd usr/lib ; ln -sf libgii.so.1.0.0 libgii.so )
( cd usr/lib ; rm -rf libgg.so.1 )
( cd usr/lib ; ln -sf libgg.so.1.0.0 libgg.so.1 )
( cd usr/lib ; rm -rf libgii.so.1 )
( cd usr/lib ; ln -sf libgii.so.1.0.0 libgii.so.1 )
( cd usr/lib ; rm -rf libgg.so )
( cd usr/lib ; ln -sf libgg.so.1.0.0 libgg.so )
